package org.eclipse.osgi.util;

import java.io.IOException;
import java.io.InputStream;
import java.lang.reflect.Field;
import java.security.AccessController;
import java.security.PrivilegedAction;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;
import java.util.Properties;

/* loaded from: org_eclipse_osgi_util.jar:org/eclipse/osgi/util/NLS.class */
public abstract class NLS {
    private static final String EXTENSION = ".properties";
    private static String[] nlSuffixes;
    static final int SEVERITY_ERROR = 4;
    static final int SEVERITY_WARNING = 2;
    private static final Object[] EMPTY_ARGS = new Object[0];
    static final Object ASSIGNED = new Object();

    protected NLS() {
    }

    public static String bind(String message, Object binding) {
        return internalBind(message, null, String.valueOf(binding), null);
    }

    public static String bind(String message, Object binding1, Object binding2) {
        return internalBind(message, null, String.valueOf(binding1), String.valueOf(binding2));
    }

    public static String bind(String message, Object[] bindings) {
        return internalBind(message, bindings, null, null);
    }

    public static void initializeMessages(final String bundleName, final Class clazz) {
        if (System.getSecurityManager() == null) {
            load(bundleName, clazz);
        } else {
            AccessController.doPrivileged(new PrivilegedAction() { // from class: org.eclipse.osgi.util.NLS.1
                @Override // java.security.PrivilegedAction
                public Object run() {
                    NLS.load(bundleName, clazz);
                    return null;
                }
            });
        }
    }

    private static String internalBind(String message, Object[] args, String argZero, String argOne) {
        if (message == null) {
            return "No message available.";
        }
        if (args == null || args.length == 0) {
            args = EMPTY_ARGS;
        }
        int length = message.length();
        int bufLen = length + (args.length * 5);
        if (argZero != null) {
            bufLen += argZero.length() - 3;
        }
        if (argOne != null) {
            bufLen += argOne.length() - 3;
        }
        StringBuffer buffer = new StringBuffer(bufLen < 0 ? 0 : bufLen);
        int i = 0;
        while (i < length) {
            char c = message.charAt(i);
            switch (c) {
                case '\'':
                    int nextIndex = i + 1;
                    if (nextIndex >= length) {
                        buffer.append(c);
                        break;
                    } else {
                        char next = message.charAt(nextIndex);
                        if (next == '\'') {
                            i++;
                            buffer.append(c);
                            break;
                        } else {
                            int index = message.indexOf(39, nextIndex);
                            if (index == -1) {
                                buffer.append(c);
                                break;
                            } else {
                                buffer.append(message.substring(nextIndex, index));
                                i = index;
                                break;
                            }
                        }
                    }
                case '{':
                    int index2 = message.indexOf(125, i);
                    if (index2 == -1) {
                        buffer.append(c);
                        break;
                    } else {
                        i++;
                        if (i >= length) {
                            buffer.append(c);
                            break;
                        } else {
                            try {
                                int number = Integer.parseInt(message.substring(i, index2));
                                if (number == 0 && argZero != null) {
                                    buffer.append(argZero);
                                } else if (number == 1 && argOne != null) {
                                    buffer.append(argOne);
                                } else if (number >= args.length || number < 0) {
                                    buffer.append("<missing argument>");
                                    i = index2;
                                    break;
                                } else {
                                    buffer.append(args[number]);
                                }
                                i = index2;
                                break;
                            } catch (NumberFormatException unused) {
                                throw new IllegalArgumentException();
                            }
                        }
                    }
                default:
                    buffer.append(c);
                    break;
            }
            i++;
        }
        return buffer.toString();
    }

    private static String[] buildVariants(String root) {
        if (nlSuffixes == null) {
            String nl = Locale.getDefault().toString();
            ArrayList result = new ArrayList(SEVERITY_ERROR);
            while (true) {
                result.add(String.valueOf('_') + nl + EXTENSION);
                int lastSeparator = nl.lastIndexOf(95);
                if (lastSeparator == -1) {
                    break;
                }
                nl = nl.substring(0, lastSeparator);
            }
            result.add(EXTENSION);
            nlSuffixes = (String[]) result.toArray(new String[result.size()]);
        }
        String root2 = root.replace('.', '/');
        String[] variants = new String[nlSuffixes.length];
        for (int i = 0; i < variants.length; i++) {
            variants[i] = String.valueOf(root2) + nlSuffixes[i];
        }
        return variants;
    }

    private static void computeMissingMessages(String bundleName, Class clazz, Map fieldMap, Field[] fieldArray, boolean isAccessible) {
        for (Field field : fieldArray) {
            if ((field.getModifiers() & 25) == 9 && fieldMap.get(field.getName()) != ASSIGNED) {
                try {
                    String value = "NLS missing message: " + field.getName() + " in: " + bundleName;
                    log(SEVERITY_WARNING, value, null);
                    if (!isAccessible) {
                        field.setAccessible(true);
                    }
                    field.set(null, value);
                } catch (Exception e) {
                    log(SEVERITY_ERROR, "Error setting the missing message value for: " + field.getName(), e);
                }
            }
        }
    }

    static void load(String bundleName, Class clazz) {
        System.currentTimeMillis();
        Field[] fieldArray = clazz.getDeclaredFields();
        ClassLoader loader = clazz.getClassLoader();
        boolean isAccessible = (clazz.getModifiers() & 1) != 0;
        int len = fieldArray.length;
        Map fields = new HashMap(len * SEVERITY_WARNING);
        for (int i = 0; i < len; i++) {
            fields.put(fieldArray[i].getName(), fieldArray[i]);
        }
        String[] variants = buildVariants(bundleName);
        for (int i2 = 0; i2 < variants.length; i2++) {
            InputStream input = loader == null ? ClassLoader.getSystemResourceAsStream(variants[i2]) : loader.getResourceAsStream(variants[i2]);
            if (input != null) {
                try {
                    try {
                        MessagesProperties properties = new MessagesProperties(fields, bundleName, isAccessible);
                        properties.load(input);
                        if (input != null) {
                            try {
                                input.close();
                            } catch (IOException unused) {
                            }
                        }
                    } catch (IOException e) {
                        log(SEVERITY_ERROR, "Error loading " + variants[i2], e);
                        if (input != null) {
                            try {
                                input.close();
                            } catch (IOException unused2) {
                            }
                        }
                    }
                } catch (Throwable th) {
                    if (input != null) {
                        try {
                            input.close();
                        } catch (IOException unused3) {
                        }
                    }
                    throw th;
                }
            }
        }
        computeMissingMessages(bundleName, clazz, fields, fieldArray, isAccessible);
    }

    static void log(int severity, String message, Exception e) {
        String statusMsg;
        switch (severity) {
            case SEVERITY_WARNING /* 2 */:
            case 3:
            default:
                statusMsg = "Warning: ";
                break;
            case SEVERITY_ERROR /* 4 */:
                statusMsg = "Error: ";
                break;
        }
        if (message != null) {
            statusMsg = String.valueOf(statusMsg) + message;
        }
        if (e != null) {
            statusMsg = String.valueOf(statusMsg) + ": " + e.getMessage();
        }
        System.err.println(statusMsg);
        if (e != null) {
            e.printStackTrace();
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: org_eclipse_osgi_util.jar:org/eclipse/osgi/util/NLS$MessagesProperties.class */
    public static class MessagesProperties extends Properties {
        private static final int MOD_EXPECTED = 9;
        private static final int MOD_MASK = 25;
        private static final long serialVersionUID = 1;
        private final String bundleName;
        private final Map fields;
        private final boolean isAccessible;

        public MessagesProperties(Map fieldMap, String bundleName, boolean isAccessible) {
            this.fields = fieldMap;
            this.bundleName = bundleName;
            this.isAccessible = isAccessible;
        }

        @Override // java.util.Hashtable, java.util.Dictionary, java.util.Map
        public synchronized Object put(Object key, Object value) {
            Object fieldObject = this.fields.put(key, NLS.ASSIGNED);
            if (fieldObject == NLS.ASSIGNED) {
                return null;
            }
            if (fieldObject == null) {
                String msg = "NLS unused message: " + key + " in: " + this.bundleName;
                NLS.log(NLS.SEVERITY_WARNING, msg, null);
                return null;
            }
            Field field = (Field) fieldObject;
            if ((field.getModifiers() & MOD_MASK) != MOD_EXPECTED) {
                return null;
            }
            try {
                if (!this.isAccessible) {
                    field.setAccessible(true);
                }
                field.set(null, value);
                return null;
            } catch (Exception e) {
                NLS.log(NLS.SEVERITY_ERROR, "Exception setting field value.", e);
                return null;
            }
        }
    }
}
